@@ -1,23 +1,9 @@
 /*
-* Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
-* Copyright 2014  Hugo Pereira Da Costa <hugo.pereira@free.fr>
-* Copyright 2018  Vlad Zahorodnii <vlad.zahorodnii@kde.org>
+* SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+* SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* SPDX-FileCopyrightText: 2018 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License or (at your option) version 3 or any later version
-* accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy
-* defined in Section 14 of version 3 of the license.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "breezedecoration.h"
@@ -45,7 +31,7 @@
 #include <QPainter>
 #include <QTextStream>
 #include <QTimer>
-#include <QVariantAnimation>
+#include <QDBusConnection>
 
 #if BREEZE_HAVE_X11
 #include <QX11Info>
@@ -243,11 +229,19 @@ namespace Breeze
         // It is important start and end value are of the same type, hence 0.0 and not just 0
         m_animation->setStartValue( 0.0 );
         m_animation->setEndValue( 1.0 );
-        m_animation->setEasingCurve( QEasingCurve::InOutQuad );
+        // Linear to have the same easing as Breeze animations
+        m_animation->setEasingCurve( QEasingCurve::Linear );
         connect(m_animation, &QVariantAnimation::valueChanged, this, [this](const QVariant &value) {
             setOpacity(value.toReal());
         });
 
+        // use DBus connection to update on breeze configuration change
+        auto dbus = QDBusConnection::sessionBus();
+        dbus.connect( QString(),
+            QStringLiteral( "/KGlobalSettings" ),
+            QStringLiteral( "org.kde.KGlobalSettings" ),
+            QStringLiteral( "notifyChange" ), this, SLOT(reconfigure()) );
+
         reconfigure();
         updateTitleBar();
         auto s = settings();
@@ -309,7 +303,7 @@ namespace Breeze
     //________________________________________________________________
     void Decoration::updateAnimationState()
     {
-        if( m_internalSettings->animationsEnabled() )
+        if( m_animation->duration() > 0 )
         {
 
             auto c = client().data();
@@ -376,7 +370,11 @@ namespace Breeze
         m_internalSettings = SettingsProvider::self()->internalSettings( this );
 
         // animation
-        m_animation->setDuration( m_internalSettings->animationsDuration() );
+
+        KSharedConfig::Ptr config = KSharedConfig::openConfig();
+        const KConfigGroup cg(config, QStringLiteral("KDE"));
+
+        m_animation->setDuration( cg.readEntry("AnimationDurationFactor", 1.0f) * 100.0f );
 
         // borders
         recalculateBorders();
