@@ -1,26 +1,14 @@
+/*
+ * SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
 #ifndef breezestyle_h
 #define breezestyle_h
 
-/*************************************************************************
- * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
- *                                                                       *
- * This program is free software; you can redistribute it and/or modify  *
- * it under the terms of the GNU General Public License as published by  *
- * the Free Software Foundation; either version 2 of the License, or     *
- * (at your option) any later version.                                   *
- *                                                                       *
- * This program is distributed in the hope that it will be useful,       *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- * GNU General Public License for more details.                          *
- *                                                                       *
- * You should have received a copy of the GNU General Public License     *
- * along with this program; if not, write to the                         *
- * Free Software Foundation, Inc.,                                       *
- * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- *************************************************************************/
-
 #include "breeze.h"
+#include "breezemetrics.h"
 #include "config-breeze.h"
 #include "breezehelper.h"
 
@@ -154,6 +142,10 @@ namespace Breeze
         //* update configuration
         void configurationChanged();
 
+        //* global configuration changed
+        void globalConfigurationChanged(int type, int arg);
+        void loadGlobalAnimationSettings();
+
         //* standard icons
         QIcon standardIconImplementation( StandardPixmap, const QStyleOption*, const QWidget* ) const;
 
@@ -464,6 +456,13 @@ namespace Breeze
         //* return true if passed widget is a menu title (KMenu::addTitle)
         bool hasAlteredBackground( const QWidget* ) const;
 
+        /*
+         * return true if the widget should be highlighted with neutral color
+         * if widget is null, check for the styleObject in option
+         * return false if the widget has the mouse hover or is focused.
+         */
+        bool hasHighlightNeutral( const QObject* widget, const QStyleOption* option, bool mouseOver, bool focus = false ) const;
+
         //*@name scrollbar button types (for addLine and subLine )
         //@{
         ScrollBarButtonType _addLineButtons = SingleButton;
