@@ -1,25 +1,12 @@
+/*
+ * SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
 #ifndef breezewindowmanager_h
 #define breezewindowmanager_h
 
-/*************************************************************************
- * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
- *                                                                       *
- * This program is free software; you can redistribute it and/or modify  *
- * it under the terms of the GNU General Public License as published by  *
- * the Free Software Foundation; either version 2 of the License, or     *
- * (at your option) any later version.                                   *
- *                                                                       *
- * This program is distributed in the hope that it will be useful,       *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- * GNU General Public License for more details.                          *
- *                                                                       *
- * You should have received a copy of the GNU General Public License     *
- * along with this program; if not, write to the                         *
- * Free Software Foundation, Inc.,                                       *
- * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- *************************************************************************/
-
 #include "breeze.h"
 #include "breezestyleconfigdata.h"
 #include "config-breeze.h"
@@ -37,17 +24,6 @@
 #include <QQuickItem>
 #endif
 
-#if BREEZE_HAVE_KWAYLAND
-namespace KWayland
-{
-    namespace Client
-    {
-        class Pointer;
-        class Seat;
-    }
-}
-#endif
-
 namespace Breeze
 {
 
@@ -105,14 +81,6 @@ namespace Breeze
         void setEnabled( bool value )
         { _enabled = value; }
 
-        //* returns true if window manager is used for moving
-        bool useWMMoveResize() const
-        { return supportWMMoveResize() && _useWMMoveResize; }
-
-        //* use window manager for moving, when available
-        void setUseWMMoveResize( bool value )
-        { _useWMMoveResize = value; }
-
         //* drag mode
         int dragMode() const
         { return _dragMode; }
@@ -143,12 +111,6 @@ namespace Breeze
         */
         void initializeBlackList();
 
-        //* initializes the Wayland specific parts
-        void initializeWayland();
-
-        //* The Wayland Seat's hasPointer property changed
-        void waylandHasPointerChanged(bool hasPointer);
-
         //@}
 
         //* returns true if widget is dragable
@@ -171,17 +133,7 @@ namespace Breeze
         void resetDrag();
 
         //* start drag
-        void startDrag( QWindow*, const QPoint& );
-
-        //* X11 specific implementation for startDrag
-        void startDragX11( QWindow*, const QPoint& );
-
-        //* Wayland specific implementation for startDrag
-        void startDragWayland( QWindow*, const QPoint& );
-
-        //* returns true if window manager is used for moving
-        /** right now this is true only for X11 */
-        bool supportWMMoveResize() const;
+        void startDrag( QWindow* );
 
         //* utility function
         bool isDockWidgetTitle( const QWidget* ) const;
@@ -206,9 +158,6 @@ namespace Breeze
         //* enability
         bool _enabled = true;
 
-        //* use WM moveResize
-        bool _useWMMoveResize = true;
-
         //* drag mode
         int _dragMode = StyleConfigData::WD_FULL;
 
@@ -293,25 +242,9 @@ namespace Breeze
         //* true if drag is locked
         bool _locked = false;
 
-        //* cursor override
-        /** used to keep track of application cursor being overridden when dragging in non-WM mode */
-        bool _cursorOverride = false;
-
         //* application event filter
         QObject* _appEventFilter = nullptr;
 
-        #if BREEZE_HAVE_KWAYLAND
-
-        //* The Wayland seat object which needs to be passed to move requests.
-        KWayland::Client::Seat* _seat = nullptr;
-
-        //* The Wayland pointer object where we get pointer events on.
-        KWayland::Client::Pointer* _pointer = nullptr;
-
-        //* latest serial which needs to be passed to the move requests.
-        quint32 _waylandSerial = 0;
-        #endif
-
         //* allow access of all private members to the app event filter
         friend class AppEventFilter;
 
